pub struct BaseSimulationNetworkExecutor<Client: GatewayClient> {
    pub client: Client,
    pub sender_address: Address,
}
A struct for executing transactions in a simulated blockchain environment. It interacts with a blockchain network for transaction simulation purposes.

Fields

client: Client

The client used to interact with the blockchain network gateway for transaction simulations.

sender_address: Address

The blockchain address of the transaction sender.

Implementations

source

impl<Client: GatewayClient> BaseSimulationNetworkExecutor<Client>

source

pub fn new(client: Client, sender_address: Address) -> Self

Constructs a new BaseSimulationNetworkExecutor.

Parameters
  • client: The client for interacting with the blockchain network gateway.
  • sender_address: The blockchain address that will be used as the sender in the transactions.
Returns

A new instance of BaseSimulationNetworkExecutor.