Struct novax_executor::QueryNetworkExecutor
source · pub struct QueryNetworkExecutor<Proxy: BlockchainProxy> {
pub gateway_url: String,
/* private fields */
}Expand description
A structure to execute smart contract queries on a real blockchain environment via a specified gateway.
This executor utilizes a blockchain proxy to communicate with the blockchain network and execute the queries.
Fields
gateway_url: StringThe URL of the gateway to the blockchain network.
Implementations
sourceimpl<Proxy: BlockchainProxy> QueryNetworkExecutor<Proxy>
impl<Proxy: BlockchainProxy> QueryNetworkExecutor<Proxy>