Struct novax_executor::ScDeployStep
source · pub struct ScDeployStep {
pub id: String,
pub tx_id: Option<String>,
pub explicit_tx_hash: Option<H256>,
pub comment: Option<String>,
pub tx: Box<TxDeploy>,
pub expect: Option<TxExpect>,
pub response: Option<TxResponse>,
}Fields
id: Stringtx_id: Option<String>explicit_tx_hash: Option<H256>comment: Option<String>tx: Box<TxDeploy>expect: Option<TxExpect>response: Option<TxResponse>Implementations
sourceimpl ScDeployStep
impl ScDeployStep
pub fn new() -> ScDeployStep
pub fn from<V>(self, expr: V) -> ScDeployStepwhere AddressValue: From<V>,
pub fn egld_value<V>(self, expr: V) -> ScDeployStepwhere BigUintValue: From<V>,
pub fn code_metadata(self, code_metadata: CodeMetadata) -> ScDeployStep
pub fn code<V>(self, expr: V) -> ScDeployStepwhere BytesValue: From<V>,
pub fn contract_code( self, expr: &str, context: &InterpreterContext ) -> ScDeployStep
👎Deprecated since 0.42.0: Please use method
code instead. To ease transition, it is also possible to call it with a tuple like so: .code((expr, context))pub fn argument(self, expr: &str) -> ScDeployStep
pub fn gas_limit<V>(self, value: V) -> ScDeployStepwhere U64Value: From<V>,
sourcepub fn call<OriginalResult>(
self,
contract_deploy: ContractDeploy<VMHooksApi<StaticApiBackend>, OriginalResult>
) -> TypedScDeploy<OriginalResult>
pub fn call<OriginalResult>( self, contract_deploy: ContractDeploy<VMHooksApi<StaticApiBackend>, OriginalResult> ) -> TypedScDeploy<OriginalResult>
Sets following fields based on the smart contract proxy:
- “function”
- “arguments”
sourcepub fn expect(self, expect: TxExpect) -> ScDeployStep
pub fn expect(self, expect: TxExpect) -> ScDeployStep
Adds a custom expect section to the tx.
sourcepub fn no_expect(self) -> ScDeployStep
pub fn no_expect(self) -> ScDeployStep
Explicitly states that no tx expect section should be added and no checks should be performed.
Note: by default a basic TxExpect::ok() is added, which checks that status is 0 and nothing else.
sourcepub fn response(&self) -> &TxResponse
pub fn response(&self) -> &TxResponse
Unwraps the response, if available.
pub fn save_response(&mut self, response: TxResponse)