pub struct TypedScCall<OriginalResult> {
    pub sc_call_step: ScCallStep,
    /* private fields */
}
SCCallStep with explicit return type.

Fields

sc_call_step: ScCallStep

Implementations

source

impl<OriginalResult> TypedScCall<OriginalResult>

source

pub fn result<RequestedResult>( &self ) -> Result<RequestedResult, TxResponseStatus>where OriginalResult: TopEncodeMulti, RequestedResult: CodecFrom<OriginalResult>,

source

pub fn from<A>(self, address: A) -> TypedScCall<OriginalResult>where AddressValue: From<A>,

source

pub fn to<A>(self, address: A) -> TypedScCall<OriginalResult>where AddressValue: From<A>,

source

pub fn egld_value<A>(self, amount: A) -> TypedScCall<OriginalResult>where BigUintValue: From<A>,

source

pub fn esdt_transfer<T, N, A>( self, token_id: T, token_nonce: N, amount: A ) -> TypedScCall<OriginalResult>where BytesValue: From<T>, U64Value: From<N>, BigUintValue: From<A>,

source

pub fn function(self, expr: &str) -> TypedScCall<OriginalResult>

source

pub fn argument<A>(self, expr: A) -> TypedScCall<OriginalResult>where BytesValue: From<A>,

source

pub fn gas_limit<V>(self, value: V) -> TypedScCall<OriginalResult>where U64Value: From<V>,

source

pub fn expect(self, expect: TxExpect) -> TypedScCall<OriginalResult>

Adds a custom expect section to the tx.

source

pub fn no_expect(self) -> TypedScCall<OriginalResult>

Explicitly states that no tx expect section should be added and no checks should be performed.

Note: by default a basic TxExpect::ok() is added, which checks that status is 0 and nothing else.

source

pub fn expect_value<ExpectedResult>( self, expected_value: ExpectedResult ) -> TypedScCall<OriginalResult>where OriginalResult: TopEncodeMulti, ExpectedResult: CodecFrom<OriginalResult> + TopEncodeMulti,

Shorthand for creating a tx expect with status “Ok” and the given value.

The given value is type-checked agains the tx return type.

source

pub fn response(&self) -> &TxResponse

Unwraps the response, if available.

source

impl<OriginalResult> TypedScCall<OriginalResult>where OriginalResult: TopEncodeMulti,

source

pub fn execute<E, RequestedResult>(self, executor: &mut E) -> RequestedResultwhere E: TypedScCallExecutor, RequestedResult: CodecFrom<OriginalResult>,

Executes the operation, on the given executor.