pub struct TypedScDeploy<OriginalResult> {
    pub sc_deploy_step: ScDeployStep,
    /* private fields */
}
ScDeployStep with explicit return type.

Fields

sc_deploy_step: ScDeployStep

Implementations

source

impl<OriginalResult> TypedScDeploy<OriginalResult>

source

pub fn result<RequestedResult>( &self ) -> Result<RequestedResult, TxResponseStatus>where OriginalResult: TopEncodeMulti, RequestedResult: CodecFrom<OriginalResult>,

source

pub fn from<A>(self, address: A) -> TypedScDeploy<OriginalResult>where AddressValue: From<A>,

source

pub fn egld_value<A>(self, amount: A) -> TypedScDeploy<OriginalResult>where BigUintValue: From<A>,

source

pub fn code_metadata( self, code_metadata: CodeMetadata ) -> TypedScDeploy<OriginalResult>

source

pub fn code<V>(self, expr: V) -> TypedScDeploy<OriginalResult>where BytesValue: From<V>,

source

pub fn contract_code( self, expr: &str, context: &InterpreterContext ) -> TypedScDeploy<OriginalResult>

👎Deprecated since 0.42.0: Please use method code instead. To ease transition, it is also possible to call it with a tuple like so: .code((expr, context))
source

pub fn gas_limit<V>(self, value: V) -> TypedScDeploy<OriginalResult>where U64Value: From<V>,

source

pub fn expect(self, expect: TxExpect) -> TypedScDeploy<OriginalResult>

Adds a custom expect section to the tx.

source

pub fn no_expect(self) -> TypedScDeploy<OriginalResult>

Explicitly states that no tx expect section should be added and no checks should be performed.

Note: by default a basic TxExpect::ok() is added, which checks that status is 0 and nothing else.

source

pub fn call( self, contract_deploy: ContractDeploy<VMHooksApi<StaticApiBackend>, OriginalResult> ) -> TypedScDeploy<OriginalResult>

Sets following fields based on the smart contract proxy:

  • “function”
  • “arguments”
source

pub fn response(&self) -> &TxResponse

Unwraps the response, if available.

source

impl<OriginalResult> TypedScDeploy<OriginalResult>where OriginalResult: TopEncodeMulti,

source

pub fn execute<E, RequestedResult>( self, executor: &mut E ) -> (Address, RequestedResult)where E: TypedScDeployExecutor, RequestedResult: CodecFrom<OriginalResult>,

Executes the operation, on the given executor.