Struct novax_executor::TypedScQuery
source · pub struct TypedScQuery<OriginalResult> {
pub sc_query_step: ScQueryStep,
/* private fields */
}Fields
sc_query_step: ScQueryStepImplementations
sourceimpl<OriginalResult> TypedScQuery<OriginalResult>
impl<OriginalResult> TypedScQuery<OriginalResult>
pub fn function(self, expr: &str) -> TypedScQuery<OriginalResult>
pub fn argument<A>(self, expr: A) -> TypedScQuery<OriginalResult>where BytesValue: From<A>,
pub fn to<A>(self, address: A) -> TypedScQuery<OriginalResult>where AddressValue: From<A>,
sourcepub fn expect(self, expect: TxExpect) -> TypedScQuery<OriginalResult>
pub fn expect(self, expect: TxExpect) -> TypedScQuery<OriginalResult>
Adds a custom expect section to the tx.
sourcepub fn no_expect(self) -> TypedScQuery<OriginalResult>
pub fn no_expect(self) -> TypedScQuery<OriginalResult>
Explicitly states that no tx expect section should be added and no checks should be performed.
Note: by default a basic TxExpect::ok() is added, which checks that status is 0 and nothing else.
sourcepub fn expect_value<ExpectedResult>(
self,
expected_value: ExpectedResult
) -> TypedScQuery<OriginalResult>where
OriginalResult: TopEncodeMulti,
ExpectedResult: CodecFrom<OriginalResult> + TopEncodeMulti,
pub fn expect_value<ExpectedResult>( self, expected_value: ExpectedResult ) -> TypedScQuery<OriginalResult>where OriginalResult: TopEncodeMulti, ExpectedResult: CodecFrom<OriginalResult> + TopEncodeMulti,
Shorthand for creating a tx expect with status “Ok” and the given value.
The given value is type-checked agains the tx return type.
sourcepub fn response(&self) -> &TxResponse
pub fn response(&self) -> &TxResponse
Unwraps the response, if available.
sourceimpl<OriginalResult> TypedScQuery<OriginalResult>where
OriginalResult: TopEncodeMulti,
impl<OriginalResult> TypedScQuery<OriginalResult>where OriginalResult: TopEncodeMulti,
sourcepub fn execute<E, RequestedResult>(self, executor: &mut E) -> RequestedResultwhere
E: TypedScQueryExecutor,
RequestedResult: CodecFrom<OriginalResult>,
pub fn execute<E, RequestedResult>(self, executor: &mut E) -> RequestedResultwhere E: TypedScQueryExecutor, RequestedResult: CodecFrom<OriginalResult>,
Executes the operation, on the given executor.