pub trait SendableTransactionConvertible {
    // Required method
    fn to_sendable_transaction(&self) -> SendableTransaction;
}
A trait for converting a type into a SendableTransaction.

This trait is implemented by various transaction and contract call representations to convert them into a SendableTransaction, which is a more frontend-friendly format.

Required Methods

source

fn to_sendable_transaction(&self) -> SendableTransaction

Converts the current instance into a SendableTransaction.

Implementations on Foreign Types

source

impl SendableTransactionConvertible for TxCall

source

impl SendableTransactionConvertible for TxDeploy

source

impl<SA, T> SendableTransactionConvertible for ContractCallWithEgld<SA, T>where SA: CallTypeApi + 'static,

Implementors