Struct novax_executor::DummyExecutor
source · pub struct DummyExecutor<Tx: SendableTransactionConvertible> {
pub tx: Tx,
pub caller: Option<Address>,
}Expand description
A structure for capturing transaction details without performing actual blockchain transactions.
It is designed for testing scenarios, especially to fetch SendableTransaction details from interactions.
Fields
tx: TxHolds the transaction details.
caller: Option<Address>Optionally holds the caller address.
Implementations
sourceimpl<Tx: SendableTransactionConvertible> DummyExecutor<Tx>
impl<Tx: SendableTransactionConvertible> DummyExecutor<Tx>
sourcepub fn get_transaction_details(&self) -> SendableTransaction
pub fn get_transaction_details(&self) -> SendableTransaction
Retrieves the transaction details encapsulated into a SendableTransaction.
sourceimpl<Tx: SendableTransactionConvertible + Default> DummyExecutor<Tx>
impl<Tx: SendableTransactionConvertible + Default> DummyExecutor<Tx>