pub trait SendableTransactionConvertible {
// Required method
fn to_sendable_transaction(&self) -> SendableTransaction;
}Expand description
A trait for converting a type into a SendableTransaction.
This trait is implemented by various transaction and contract call representations
to convert them into a SendableTransaction, which is a more frontend-friendly format.
Required Methods
sourcefn to_sendable_transaction(&self) -> SendableTransaction
fn to_sendable_transaction(&self) -> SendableTransaction
Converts the current instance into a SendableTransaction.